#!/bin/sh

if [ ! -f ./mtdutil/eraseall ] || [ ! -f ./mtdutil/nandwrite ]; then
	echo "Command not found \"./mtdutil/eraseall\" or \"./mtdutil/nandwrite\""
	exit 0
fi

install_mtdutil()
{
    echo "Install mtdutil -------------------------------------------"
    cp -av ./mtdutil/eraseall   /usr/sbin
    cp -av ./mtdutil/jffs2dump  /usr/sbin
    cp -av ./mtdutil/mtd_debug  /usr/sbin 
    cp -av ./mtdutil/nanddump   /usr/sbin
    cp -av ./mtdutil/nandflag   /usr/sbin
    cp -av ./mtdutil/nandmark   /usr/sbin
    cp -av ./mtdutil/nandwrite  /usr/sbin
    cp -av ./mtdutil/mkfs.jffs2 /sbin
}

erasedevice()
{
    mknod /dev/mtd0 c 90 0  2>/dev/null
    mknod /dev/mtd1 c 90 2  2>/dev/null
    mknod /dev/mtd2 c 90 4  2>/dev/null
    mknod /dev/mtdblock0 b 31 0  2>/dev/null
    mknod /dev/mtdblock1 b 31 1  2>/dev/null
    mknod /dev/mtdblock2 b 31 2  2>/dev/null

    echo -n "Erase: /dev/mtd0 ....."
    ./mtdutil/eraseall -j /dev/mtd0 >/dev/null
    echo "done"
    echo -n "Erase: /dev/mtd1 ....."
    ./mtdutil/eraseall -j /dev/mtd1 >/dev/null
    echo "done"
    echo -n "Erase: /dev/mtd2 ....."
    ./mtdutil/eraseall -j /dev/mtd2 >/dev/null
    echo "done"
}

install_jffs2()
{
    if [ ! -f ./rootdiskimage.jffs2 ] || [ ! -f ./setupdiskimage.jffs2 ]; then
        echo "Not found \"rootdiskimage.jffs2\" or \"setupdiskimage.jffs2\""
        exit 0
    fi
    echo "Install nand flash (jffs2 image) --------------------------"
    erasedevice
    echo -n "Write: rootdiskimage.jffs2  => /dev/mtd0 ....."
    ./mtdutil/nandwrite --jffs2 /dev/mtd0 ./rootdiskimage.jffs2 >/dev/null
    echo "done"
    echo -n "Write: setupdiskimage.jffs2 => /dev/mtd1 ....."
    ./mtdutil/nandwrite --jffs2 /dev/mtd1 ./setupdiskimage.jffs2 >/dev/null
    echo "done"
}

install_cramfs()
{
    if [ ! -f ./rootdiskimage.cramfs ] || [ ! -f ./setupdiskimage.jffs2 ]; then
        echo "Not found \"rootdiskimage.cramfs\" or \"setupdiskimage.jffs2\""
        exit 0
    fi
    echo "Install nand flash (cramfs image) -------------------------"
    erasedevice
    echo -n "Write: rootdiskimage.cramfs => /dev/mtd0 ....."
    cp ./rootdiskimage.cramfs /dev/mtd0 >/dev/null
    echo "done"
    echo -n "Write: setupdiskimage.jffs2 => /dev/mtd1 ....."
    ./mtdutil/nandwrite --jffs2 /dev/mtd1 ./setupdiskimage.jffs2 >/dev/null
    echo "done"
}

case "$1" in
    "all")
    install_mtdutil
    install_jffs2
    ;;
    "jffs2")
    install_jffs2
    ;;
    "cramfs")
    install_cramfs
    ;;
    "util")
    install_mtdutil
    ;;
    *)
    echo "Usage: install.sh { jffs2 | cramfs | util | all }"
    exit 0
    ;;
esac

echo "*** Finish !! ***"
